@@ -1,7 +1,7 @@
 import sys
 from ds_format.misc import UsageError, check
 import ds_format as ds
-import pst
+from ds_format import misc
 
 def size(*args, **opts):
 	'''
@@ -32,4 +32,4 @@ def size(*args, **opts):
 		if var is not None:
 			var = ds.find(d, 'var', var)
 	size = ds.size(d, var)
-	sys.stdout.buffer.write(pst.encode(size) + b'\n')
+	sys.stdout.buffer.write(misc.encode(size) + b'\n')
